embassy-net

Crates

git

Versions

default

Flavors

Routes

Struct Routes 

pub struct Routes<'d> { /* private fields */ }
A routing table, returned by Stack::routes.

Implementations

Source

impl<'d> Routes<'d>

pub fn add(&self, route: Route) -> Result<(), RouteError>

Add a route.

Errors
  • NotUnicast: if via_router is not a unicast address.
  • Full: if the table has no room. Only possible without the alloc feature, where the limit is ROUTE_COUNT.
pub fn remove(&self, index: usize) -> Route

Remove the route at index and return it.

Panics

Panics if index is out of bounds.

pub fn retain(&self, f: impl FnMut(&Route) -> bool)

Keep only the routes for which f returns true.

pub fn clear(&self)

Remove all routes.

pub fn iter(&self) -> impl Iterator<Item = Route> + 'd

Iterate over the routes.

pub fn len(&self) -> usize

Number of routes.

pub fn is_empty(&self) -> bool

Whether there are no routes.

pub fn add_default_ipv4_route( &self, gateway: Ipv4Addr, iface: IfaceHandle, ) -> Result<Option<Route>, RouteError>

Add a default ipv4 gateway (ie. “ip route add 0.0.0.0/0 via gateway dev iface”).

Returns the previous default route, if any. On error the previous default route is kept.

Errors
  • NotUnicast: if gateway is not a unicast address.
  • Full: if the table has no room. Only possible without the alloc feature, where the limit is ROUTE_COUNT.
pub fn add_default_ipv6_route( &self, gateway: Ipv6Addr, iface: IfaceHandle, ) -> Result<Option<Route>, RouteError>

Add a default ipv6 gateway (ie. “ip -6 route add ::/0 via gateway dev iface”).

Returns the previous default route, if any. On error the previous default route is kept.

Errors
  • NotUnicast: if gateway is not a unicast address.
  • Full: if the table has no room. Only possible without the alloc feature, where the limit is ROUTE_COUNT.
pub fn default_ipv4_route(&self) -> Option<Route>

Returns the ipv4 default route if there is one in the route table.

pub fn default_ipv6_route(&self) -> Option<Route>

Returns the ipv6 default route if there is one in the route table.

pub fn remove_default_ipv4_route(&self) -> Option<Route>

Remove the default ipv4 gateway, returning it if it existed.

pub fn remove_default_ipv6_route(&self) -> Option<Route>

Remove the default ipv6 gateway, returning it if it existed.